/* Copyright (c)2012 Sky Co., LTD. All rights reserved. */

#import <Foundation/Foundation.h>

/**
 * Base64で暗号化/復号化するための機能を提供します。
 * @since   SKYSEA8.0
 * @author  T.Maruyama
 * @date    2012/09/07
 */
@interface Base64Converter : NSObject

/**
 * Base64で暗号化します。
 * @param   [in]    data    元データ
 * @return  Base64で暗号化後の文字列を返します。
 */
+ (NSString*) encodeStringWithData:(NSData*)data;

/**
 * Base64で暗号化します。
 * @param   [in]    bytes   元データ
 * @param   [in]    length  元データのサイズ
 * @return  Base64で暗号化後の文字列を返します。
 */
+ (NSString*) encodeStringWithBytes:(const void*)bytes length:(NSUInteger)length;

/**
 * Base64で復号化します。
 * @param   [in]    string  元データ
 * @return  Base64で復号化後の文字列を返します。
 */
+ (NSData*) decodeDataWithString:(NSString*)string;

@end

/* Copyright (c)2012 Sky Co., LTD. All rights reserved. */
