// Copyright (c) 2015年 Sky Co., LTD. All rights reserved.

#import <Cocoa/Cocoa.h>

#define kCUCPV_AnimationFrameRate_Default   (20)
#define kCUCPV_AnimationFrameRate_Min       (2)
#define kCUCPV_AnimationFrameRate_Max       (60)

#define kCUCPV_CircleCount_Default              (6)
#define kCUCPV_CircleCount_Min                  (4)
#define kCUCPV_CircleCount_Max                  (20)
#define kCUCPV_CircleRotateInterval_Default     (2.0)
#define kCUCPV_CircleRotateInterval_Min         (1.0)
#define kCUCPV_CircleRotateInterval_Max         (30.0)
#define kCUCPV_ProgressRotateInterval_None      (0.0)
#define kCUCPV_ProgressRotateInterval_Default   kCUCPV_ProgressRotateInterval_None
#define kCUCPV_ProgressRotateInterval_Max       (300.0)
#define kCUCPV_CircleSpacing_Default            (0.2)
#define kCUCPV_CircleSpacing_Min                (0.01)
#define kCUCPV_CircleSpacing_Max                (1.0)
#define kCUCPV_CircleSize_Default               (NSMakeSize((CGFloat)6.0, (CGFloat)6.0))
#define kCUCPV_CircleSize_Min                   (NSMakeSize((CGFloat)2.0, (CGFloat)2.0))

/**
 * くるくるプログレスビュー
 */
@interface CircleProgressView : NSView {
@private
    NSTimer* _animationTimer;           /// アニメーション用のタイマー
    NSTimeInterval _animationInterval;  /// アニメーションタイマーの間隔(s)(プロパティ「animationFramerate」から設定される)

    NSInteger _circleCount;                 /// プログレスの円の数(def: 6, min: 4, max:20)
    NSTimeInterval _circleRotateInterval;   /// 円が１周する間隔(def: 2.0(s), min: 1.0(s), max: 30.0(s))
    NSTimeInterval _circleSpacing;          /// 円が動き出してから次の円が動き出すまでの間隔(def: 0.2(s), min: 0.01(s), max: 1.0(s))
    NSSize _circleSize;                     /// プログレスの円のサイズ(pixel)(def: (6, 6), min: (2, 2), max: viewサイズの1/4)
    NSTimeInterval _progressRotateInterval; /// プログレス全体が１周する間隔
                                            /// （def:0, min: _circleRotateInterval × 2(s), max: 300.0(s)）。
                                            ///   0ならプログレスは回転しない。
    
    NSTimeInterval _period; /// 描画位置の分割数。大きくすると、細かい描画が可能。(def:100.0)

    // 内部計算用
    NSTimeInterval _baseTime;
    NSTimeInterval _toPosFactor;
    NSTimeInterval _toRadianFactor;
    NSTimeInterval _baseTimeProgress;
    NSTimeInterval _toPosFactorProgress;
    NSTimeInterval _toRadianFactorProgress;
    CGPoint _circlePosFactor;
}
@property(assign, readwrite) NSInteger animationFramerate;
@property(assign, readwrite) NSInteger circleCount;
@property(assign, readwrite) NSTimeInterval circleRotateInterval;
@property(assign, readwrite) NSTimeInterval circleSpacing;
@property(assign, readwrite) NSSize circleSize;
@property(assign, readwrite) NSTimeInterval progressRotateInterval;
@property(assign, readonly) BOOL isStartAnimation;


/**
 * アニメーションを開始する
 */
- (void)startAnimation;

/**
 * アニメーションを停止する
 */
- (void)stopAnimation;

@end

// Copyright (c) 2015年 Sky Co., LTD. All rights reserved.
