/* Copyright (c)2012 Sky Co., LTD. All rights reserved. */

#import <Foundation/Foundation.h>

/**
 * ファイルが変更された際の通知を受け取るためのインターフェースを定義します。
 * @since   SKYSEA8.0
 * @author  Morio Tanioku
 * @date    2012/09/18
 */
@protocol FileWatchdogDelegate <NSObject>

/**
 * ファイルが変更された際に呼び出されます。
 */
- (void)doOnChange;

@end

/**
 * 指定されたファイルの変更を監視するための機能を提供します。
 * @since   SKYSEA8.0
 * @author  Morio Tanioku
 * @date    2012/09/18
 */
@interface FileWatchdog : NSObject {
    NSTimer*    _watchdogTimer;         /**< 定期的にファイルを監視するためのタイマー */
    NSString*   _path;                  /**< 監視対象のファイルパス */
    NSDate*     _previousModifiedDate;  /**< 前回更新日時 */
    id<FileWatchdogDelegate> _delegate; /**< 変更があった場合の通知先 */
}

@property(retain, readwrite) id<FileWatchdogDelegate> delegate;

/**
 * ファイルの監視を開始します。
 * @param   [in]    fileName    監視対象のファイル名
 * @param   [in]    interval    監視周期(秒)
 */
- (id)initWithFileName:(NSString*)fileName interval:(NSTimeInterval)interval;

/**
 * 監視を終了します。
 */
- (void)shutdown;

@end

/* Copyright (c)2012 Sky Co., LTD. All rights reserved. */
