//  Copyright (c) 2015年 Sky Co., LTD. All rights reserved.

/**
 * 実行ループで待機するスレッドクラス
 * このクラスは継承し、threadInit、threadExitを実装して下さい。
 */

#import <Foundation/Foundation.h>

/**
 * 実行ループで待機するスレッド
 * @attention   入力ソースが登録されていなければ、すぐに終了します。
 */
@interface RunLoopThread : NSThread

/**
 * スレッド初期化処理
 * スレッド開始後、実行ループで待機する前に呼び出されます。
 * ここで必要な入力ソースを登録して下さい。
 * @return  YES 実行ループで待機する
 * @return  NO  実行ループで待機せず、スレッドを終了する
 */
- (BOOL)threadInit;

/**
 * スレッド終了処理
 * スレッドが終了する前に呼び出されます。
 * ここで登録していた入力ソースを破棄して下さい。
 */
- (void)threadExit;

@end

//  Copyright (c) 2015年 Sky Co., LTD. All rights reserved.
