/* Copyright (c)2012 Sky Co., LTD. All rights reserved. */

#import <Foundation/Foundation.h>

/**
 * 文字列を操作するための機能を提供します。
 * @since   SKYSEA8.0
 * @author  Morio Tanioku
 * @date    2012/08/06
 */
@interface StringUtils : NSObject

/**
 * UTF-8NFCに正規化した文字列を取得します。
 * @param   [in]    source  文字列
 * @return  UTF-8NFCに正規化した文字列を返します。
 */
+ (NSString*)toUTF8NFCWithString:(NSString*)source;

/**
 * UTF-8NFCに正規化した文字列を取得します。
 * @param   [in]    source  NULL終端の文字列
 * @return  UTF-8NFCに正規化した文字列を返します。
 */
+ (NSString*)toUTF8NFCWithCString:(const char*)source;

/**
 * Shift_JISに変換した文字列を取得します。
 * @param   [in]    source  文字列
 * @return  Shift_JISに変換した文字列を返します。
 */
+ (NSString*)toSJISWithString:(NSString*)source;

/**
 * Shift_JISに変換した文字列を取得します。
 * @param   [in]    source  NULL終端の文字列
 * @return  Shift_JISに変換した文字列を返します。
 */
+ (NSString*)toSJISWithCString:(const char*)source;

/**
 * 文字エンコーディングを変換します。
 * @param   [in]    source      変換元の文字列
 * @param   [in]    encoding    変換したい文字エンコーディング
 * @return  変換後の文字列を返します。
 */
+ (NSString*)transferEncoding:(NSString*)source encoding:(NSStringEncoding)encoding;

/**
 * ワイルドカードを使用した文字列比較を行います。
 * @param   [in]    search    比較文字列(ワイルドカードを含む)
 * @param   [in]    target    比較対象文字列
 * @retval  YES     一致している
 * @retval  NO      一致していない
 */
+ (BOOL)isMatchWithWildCard:(const char*)search target:(const char*)target;

@end

/* Copyright (c)2012 Sky Co., LTD. All rights reserved. */
