//
//  NSDate+SKYSEALog.h
//  SKYSEALog
//
//  Created by misaki on 2013/04/08.
//
//

#import <Foundation/Foundation.h>
#import <CommonUtils/Windows.h>

/**
 *  @brief  範囲確認の結果
 */
enum _SCVDateRangeResult {
    SCVDateRangeNone = -1,  // 範囲指定なし
    SCVDateRangeIn,         // 範囲内
    SCVDateRangeBefore,     // 範囲より前
    SCVDateRangeAfter       // 範囲より後
};
typedef NSInteger SCVDateRangeResult;

@interface NSDate (SKYSEACommon)
+ (NSDate*)date1601;
- (NSTimeInterval) timeIntervalSince1601;

- (void) toSYSTEMTIME:(SYSTEMTIME*)_systemtime;
- (void) toFILETIME:(FILETIME*)_filetime;
+ (NSDate*) dateWithSYSTEMTIME:(SYSTEMTIME*)_systemtime;
// FILETIME（ローカル）からNSDateを作成
+ (NSDate*) dateWithFILETIME:(FILETIME*)_filetime;
// FILETIME（UTC）からNSDateを作成
+ (NSDate*) dateWithUTCFILETIME:(FILETIME*)_utc_filetime;

/**
 * 指定された日時からの経過秒を取得します。
 * @param   [in]    anotherDate 基準日時
 * @return  anotherDateからの経過秒を返します。
 */
- (int32_t)secondsSinceDate:(NSDate*)anotherDate;

/**
 * タイムゾーンの標準時からの差分文字列を取得します。
 */
+ (NSString*)timeZoneOffsetString;

/**
 * @brief   日時が指定された日付の範囲内かどうか判定する。
 * @detail  begin <= self <= end なら範囲内。
 *          beginがnilなら、self <= end なら範囲内。
 *          endがnilなら、begin <= なら範囲内。
 * @param   [in]    begin   開始日時
 * @param   [in]    end     終了日時
 * @retval  SCVDateRangeNone    範囲指定なし。begin, end共にnil。
 * @retval  SCVDateRangeIn      範囲内。
 * @retval  SCVDateRangeBefore  範囲より前。
 * @retval  SCVDateRangeAfter   範囲より後。
 */
- (SCVDateRangeResult)SCVDateRangeWithBegin:(NSDate*)begin end:(NSDate*)end;

/**
 * @brief   SKYSEAでよく使う日付文字列を返す(yyyy/MM/dd HH:mm:ss:SSS)
 * @return  日付文字列
 */
- (NSString*)stringSCVDateFormat;

@end