//
//  NSFileManager+SKYSEACommon.h
//  CommonUtils
//
//  Created by 丸山 隆夫 on 2015/01/13.
//  Copyright (c) 2015年 Sky Co., LTD. All rights reserved.
//

#import <Foundation/Foundation.h>

/**
 * @brief   NSFileManagerのSKYSEA拡張
 * @sa ------------------------------------------------------------
 - $Upd>    SKYSEA10.000.11 Mac Yosemite対応 - Safari対応
 * @test    2015/01/09 ta-maruyama  新規作成
 */
@interface NSFileManager (SKYSEACommon)

/**
 * @brief   指定パスの権限を設定する。
 *          権限が同じであれば何もしない。
 *          setAttributesの拡張
 * @param   [in]        permission  権限を表すNSNumber
 * @param   [in]        path        対象のパス
 * @param   [in/out]    error       エラー情報
 * @retval  YES 設定できた
 * @retval  NO  設定に失敗（詳細はerrを参照）（設定取得に失敗している可能性もあり）
 */
- (BOOL) setSCVCommonPermission:(NSNumber*)permission ofItemAtPath:(NSString*)path error:(NSError**)error;

/**
 * @brief   copyItemAtPathの拡張
 *          コピー先のファイルがあれば削除してからコピーする
 * @attention   ファイルのみ対応
 * @param   [in]        srcPath     コピー元ファイルのパス
 * @param   [in]        dstPath     コピー先ファイルのパス
 * @param   [in/out]    error       エラー情報
 * @retval  YES コピー成功
 * @retval  NO  コピー失敗（詳細はerrorを参照）（コピー元が存在しない、コピー先ファイルの削除に失敗している可能性もある）
 */
- (BOOL) copyItemSCVCommonAtPath:(NSString*)srcPath toPath:(NSString*)dstPath error:(NSError**)error;

@end
