// Copyright (c) 2015年 Sky Co., LTD. All rights reserved.

#import <Foundation/Foundation.h>

#import <SystemConfiguration/SystemConfiguration.h>

@protocol CUDynamicStoreObserverDelegate;

/**
 * DynamicStoreの変更を監視する
 */
@interface CUDynamicStoreObserver : NSObject {
@private
    id<CUDynamicStoreObserverDelegate> _delegate;   // 変更があった事を伝える
    
    SCDynamicStoreRef _store;               // DynamicStore
    CFRunLoopSourceRef _storeRunLoopSource; // DynamicStoreのRunLoopSource
    
    NSArray* _observeKeys;      // 監視するキー
    NSArray* _observePatterns;  // 監視するキーのパターン
}
@property(readwrite) id<CUDynamicStoreObserverDelegate> delegate;
@property(assign, readonly) SCDynamicStoreRef store;
@property(retain, readwrite) NSArray* observeKeys;
@property(retain, readwrite) NSArray* observePatterns;

/**
 * 監視を開始する
 */
- (void)start;

/**
 * 監視を開始する
 * キー、パターンリスト付き
 */
- (void)startWithKeys:(NSArray*)keys patterns:(NSArray*)patterns;

/**
 * 監視を停止する
 */
- (void)stop;

@end

// Copyright (c) 2015年 Sky Co., LTD. All rights reserved.
