//  Copyright (c) 2015年 Sky Co., LTD. All rights reserved.

/**
 * メソッド呼び出し機能付きRunLoopSource
 * RunLoopSourceをクラス化し、シグナル時にメソッド呼び出しの機能を追加
 * @attention attatch〜を実行した場合、不要になった場合は必ずinvalidateを呼び出して下さい
 */
@interface InvocationRunLoopSource : NSObject {
@private
    CFRunLoopSourceRef _source; /// RunLoopSource
    CFRunLoopRef _runLoop;      /// アタッチされた実行ループ
    NSDictionary* _contextInfo; /// シグナル時に呼び出される関数に渡される情報
}

/**
 * 実行ループにRunLoopSourceをアタッチする
 * @param   target      呼び出すメソッドを持つオブジェクト
 * @param   aSelector   呼び出すメソッド
 * @param   userInfo    メソッドに渡すパラメータ(nilでもOK)
 */
- (void)attatchToCurrentRunLoopWithTarget:(id)target selector:(SEL)aSelector userInfo:(id)userInfo;

/**
 * 実行ループにRunLoopSourceをアタッチする
 * @param   invocation  シグナル時に実行するNSInvocation
 */
- (void)attatchToCurrentRunLoopWithInvocation:(NSInvocation*)invocation;

/**
 * RunLoopSourceの無効化
 */
- (void)invalidate;

/**
 * RunLoopSourceのシグナル化
 */
- (void)signal;

@end

//  Copyright (c) 2015年 Sky Co., LTD. All rights reserved.
