/* Copyright (c)2012 Sky Co., LTD. All rights reserved. */

#import <Foundation/Foundation.h>

@class WaitableQueue;

/**
 * プロセス間通信のクライアント機能を提供します。
 * @since   SKYSEA8.0
 * @author  Morio Tanioku
 * @date    2012/10/03
 */
@interface MessagingClient : NSObject {
    NSString*       _serviceName;   /**< サービス名(プロセス間通信のプロキシ名として使用) */
    id              _upProxy;       /**< クライアントからサーバーにデータを渡すためのプロキシ */
    id              _downProxy;     /**< サーバーからクライアントへのデータを取得するためのプロキシ */
    NSThread*       _readerThread;  /**< サーバーからクライアントへのデータを読み出すためのスレッド */
    WaitableQueue*  _readableQueue; /**< サーバーからのデータを復号化したデータ群 */
}

/**
 * プロセス間通信のクライアント機能を開始します。
 * @param   [in]    name        サービス名
 * @param   [in]    threadName  内部スレッドに付ける名前
 * @return  自身を返します。
 */
- (id)initWithName:(NSString*)name threadName:(NSString *)threadName;

/**
 * サーバーから受信した全てのデータを取得し、内部バッファを空にします。
 * @return  保持していた全てのデータを返します。
 */
- (NSArray*)read;

/**
 * サーバーから受信した全てのデータを取得し、内部バッファを空にします。
 * @param   [in]    timeout データ取得のタイムアウト値(秒)
 * @param   [out]   buffer  保持している全てのデータを取得するためのバッファ
 * @retval  YES データが取得できた場合
 * @retval  NO  データが取得できなかった or タイムアウトした場合
 */
- (Boolean)readWithTimeout:(NSTimeInterval)timeout intoBuffer:(NSArray**)buffer;

/**
 * サーバーにデータを渡します。
 * @param   [in]    message 追加したいデータ
 * @retval  YES データを書き込めた場合
 * @retval  NO  データを書き込めなかった場合
 */
- (Boolean)write:(id<NSCoding>)message;

/**
 * プロセス間通信を終了します。
 */
- (void)shutdown;

@end

/* Copyright (c)2012 Sky Co., LTD. All rights reserved. */
