//
//  NSString+SKYSEACommon.h
//  CommonUtils
//
//  Created by 東原 和輝 on 2014/03/15.
//  Copyright (c) 2014年 Sky Co., LTD. All rights reserved.
//

#import <Foundation/Foundation.h>

@interface NSString (SKYSEACommon)

/**
 * 先頭から指定したバイト数の文字列を切り出す。
 * @attention 指定したバイト数で表現可能な文字数分を切り出すため、
 *            切り出した文字列が指定したバイト数になるとは限らない。
 * @param   [in]    bytes    切り出すバイト数
 * @return  切り出した文字列
 */
- (NSString*)substringWithBytes:(NSUInteger)bytes;

/**
 * 特定の文字種だけを含んでいるかどうかテストします。
 * @param   [in]    charSet テストする文字種
 * @return  charSetに含まれている文字だけで成り立っている場合はYES、それ以外はNOを返します。
 */
- (Boolean)isIncludeOnlyCharacterFromSet:(NSCharacterSet*)charSet;
    
/**
 * 文字列の左Trim
 *  @param  [in]    characterSet    Trimする文字の集合
 *  @return Trimした文字列
 */
- (NSString*)stringByTrimmingLeadingCharactersInSet:(NSCharacterSet *)characterSet;

/**
 * 文字列の右Trim
 *  @param  [in]    characterSet    Trimする文字の集合
 *  @return Trimした文字列
 */
- (NSString*)stringByTrimmingTrailingCharactersInSet:(NSCharacterSet *)characterSet;

#ifndef __OBJC_GC__
/**
 * 正規表現で分割した文字列のリストを返します。
 * @param   [in]    separator   分割正規表現文字列
 * @return 正規表現で分割した文字列のリスト
 */
- (NSArray *)componentsSeparatedByRegexp:(NSString *)separator;
#endif
// nilかどうか、空白（＆改行）でTrimした後にブランクかどうか、をテストします。
+ (BOOL)isBlankOrNilAfterWhitespaceTrimString:(NSString*)str;

@end
