//
//  SCVLogger.h
//  ScvLib
//
//  Created by 丸山　隆夫 on 12/07/27.
//  Copyright (c) 2012年 Sky. All rights reserved.
//

#import <Foundation/Foundation.h>

// ログ出力レベル
typedef enum {
    LogLevel_SCVLogger_All = 0,
    LogLevel_SCVLogger_Research = 0,
    LogLevel_SCVLogger_Info,
    LogLevel_SCVLogger_Start,
    LogLevel_SCVLogger_End,
    LogLevel_SCVLogger_Warning,
    LogLevel_SCVLogger_Error,
    LogLevel_SCVLogger_Fatal,
    LogLevel_SCVLogger_None
} LogLevel_SCVLogger;

// ログ出力モード
typedef enum {
    LogMode_SCVLogger_SCV = 0,
    LogMode_SCVLogger_Local,
    LogMode_SCVLogger_Custom,
} LogMode_SCVLogger;

// 各レベル毎のログ出力マクロ
#define SCVLOG_Research(format, ...)    outputSCVLog(LogLevel_SCVLogger_Research, __LINE__, __PRETTY_FUNCTION__, format, ##__VA_ARGS__)
#define SCVLOG_Info(format, ...)        outputSCVLog(LogLevel_SCVLogger_Info,     __LINE__, __PRETTY_FUNCTION__, format, ##__VA_ARGS__)
#define SCVLOG_Warning(format, ...)     outputSCVLog(LogLevel_SCVLogger_Warning,  __LINE__, __PRETTY_FUNCTION__, format, ##__VA_ARGS__)
#define SCVLOG_Error(format, ...)       outputSCVLog(LogLevel_SCVLogger_Error,    __LINE__, __PRETTY_FUNCTION__, format, ##__VA_ARGS__)
#define SCVLOG_Fatal(format, ...)       outputSCVLog(LogLevel_SCVLogger_Fatal,    __LINE__, __PRETTY_FUNCTION__, format, ##__VA_ARGS__)
// 開始・終了用ログ出力マクロ
#define SCVLOG_Start()  outputSCVLog(LogLevel_SCVLogger_Start, __LINE__, __PRETTY_FUNCTION__, @"==========<開始>==========")
#define SCVLOG_End()    outputSCVLog(LogLevel_SCVLogger_End,   __LINE__, __PRETTY_FUNCTION__, @"----------<終了>----------\n")
// ログ出力モード設定マクロ
#define SCVLOG_SetLogMode(mode)    setSCVLogMode(mode)
// ログカスタム設定用マクロ
#define SCVLOG_SetLogSetting(key, value)    setSCVLogSetting(key, value)
// ログ出力プロセス名偽装
#define SCVLOG_SetLogProcessName(process)    setSCVLogProcessName(process)

// ログ出力SKYSEAアプリディレクトリ指定
#define SCVLOG_SetSKYSEAAppDirectory(skyseaDir)                                setSCVLogSKYSEADir(skyseaDir)
#define SCVLOG_SetSKYSEAAppDirectoryAndProcessName(skyseaDir, process)         setSCVLogSKYSEADir2(skyseaDir, process)

// ログ出力判定
#define SCVLOG_IsResearchEnabled()    canOutputSCVLog(LogLevel_SCVLogger_Research)
#define SCVLOG_IsInfoEnabled()        canOutputSCVLog(LogLevel_SCVLogger_Info)
#define SCVLOG_IsWarningEnabled()     canOutputSCVLog(LogLevel_SCVLogger_Warning)
#define SCVLOG_IsErrorEnabled()       canOutputSCVLog(LogLevel_SCVLogger_Error)
#define SCVLOG_IsFatalEnabled()       canOutputSCVLog(LogLevel_SCVLogger_Fatal)


// ログ出力関数
void outputSCVLog(LogLevel_SCVLogger level, int line, const char* function, NSString* format, ...);
BOOL canOutputSCVLog(LogLevel_SCVLogger level);

// ログ出力モード設定関数
void setSCVLogMode(LogMode_SCVLogger mode);

#define LogKey_SCVLogger_Path       @"LogKeySCVLoggerPath"
#define LogKey_SCVLogger_Level      @"LogKeySCVLoggerLevel"
#define LogKey_SCVLogger_Size       @"LogKeySCVLoggerSize"
#define LogKey_SCVLogger_BackupIdx  @"LogKeySCVLoggerBackupIdx"
// カスタムモード用の各種設定関数
void setSCVLogSetting(NSString* settingKey, id value);

// ログ出力プロセス名偽装
void setSCVLogProcessName(NSString *processName);

// SKYSEAホームディレクトリ指定
void setSCVLogSKYSEADir(NSString *skyseaDir);

// SKYSEAホームディレクトリとプロセス名指定
void setSCVLogSKYSEADir2(NSString *skyseaDir, NSString *processName);

// SCVLoggerバックアップ処理
BOOL BackupOfSCVLogger(NSString* backupFilePath, NSString* backupPath, NSInteger maxCount, NSError** err);
